/* 
 
Copyright 2006 Rene Grothmann, modified by Eric Hakenholz

This file is part of C.a.R. software.

    C.a.R. is a free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    C.a.R. is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
 
 package rene.zirkel.dialogs;

import java.awt.Frame;

import rene.gui.CloseDialog;

public class HelpCloseDialog extends CloseDialog {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	Frame F;

	public HelpCloseDialog(final Frame f, final String s, final boolean modal) {
		super(f, s, modal);
		F = f;
	}

	@Override
	public void showHelp() {

	}
}
